// globals.h -- Global variables
//
//  Copyright (C) 2006, 2007, 2011  Miles Bader <miles@gnu.org>
//
// This source code is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 3, or (at
// your option) any later version.  See the file COPYING for more details.
//
// Written by Miles Bader <miles@gnu.org>
//

#ifndef SNOGRAY_GLOBALS_H
#define SNOGRAY_GLOBALS_H


namespace snogray {


// If true, don't output random informational notes to std::cout.
//
extern bool quiet;


}

#endif // SNOGRAY_GLOBALS_H

// arch-tag: 1ea2a088-c2a4-438b-b4b9-3d95225b93bd
